obfuscator

package
v0.0.0-...-41e8347 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 26, 2026 License: MIT Imports: 8 Imported by: 0

README

Iguana

  • Not currently available for public, but in a future a I will make it public

Documentation

Overview

this package is suppose to work internally, I will make this setup available ti public in a future

Index

Constants

This section is empty.

Variables

var ErrObfuscatorServer = errors.New("The obfuscator is not active")

Functions

func JS

func JS(code []byte, url string, prefix string) (string, error)

Types

type Obfuscator

type Obfuscator struct {
	Code    string            `json:"code"`
	Options ObfuscatorOptions `json:"options"`
}

type ObfuscatorAnswer

type ObfuscatorAnswer struct {
	Code      string `json:"code"`
	SourceMap string `json:"sourceMap"`
}

type ObfuscatorOptions

type ObfuscatorOptions struct {
	Compact                        bool     `json:"compact"`
	ControlFlowFlattening          bool     `json:"controlFlowFlattening"`
	ControlFlowFlatteningThreshold float32  `json:"controlFlowFlatteningThreshold"`
	DeadCodeInjection              bool     `json:"deadCodeInjection"`
	DeadCodeInjectionThreshold     float32  `json:"deadCodeInjectionThreshold"`
	DebugProtection                bool     `json:"debugProtection"`
	DebugProtectionInterval        bool     `json:"debugProtectionInterval"`
	DisableConsoleOutput           bool     `json:"disableConsoleOutput"`
	DomainLock                     []string `json:"domainLock"`
	IdentifierNamesGenerator       string   `json:"identifierNamesGenerator"`
	IdentifiersPrefix              string   `json:"identifiersPrefix"`
	RenameGlobals                  bool     `json:"renameGlobals"`
	ReservedNames                  []string `json:"reservedNames"`
	ReservedStrings                []string `json:"reservedStrings"`
	RotateStringArray              bool     `json:"rotateStringArray"`
	RotateStringArrayEnabled       bool     `json:"rotateStringArrayEnabled"`
	Seed                           int      `json:"seed"`
	SelfDefending                  bool     `json:"selfDefending"`
	SourceMap                      bool     `json:"sourceMap"`
	SourceMapBaseURL               string   `json:"sourceMapBaseUrl"`
	SourceMapFileName              string   `json:"sourceMapFileName"`
	SourceMapMode                  string   `json:"sourceMapMode"`
	SourceMapSeparate              bool     `json:"sourceMapSeparate"`
	StringArray                    bool     `json:"stringArray"`
	StringArrayEncoding            string   `json:"stringArrayEncoding"`
	StringArrayEncodingEnabled     bool     `json:"stringArrayEncodingEnabled"`
	StringArrayThreshold           float32  `json:"stringArrayThreshold"`
	StringArrayThresholdEnabled    bool     `json:"stringArrayThresholdEnabled"`
	Target                         string   `json:"target"`
	TransformObjectKeys            bool     `json:"transformObjectKeys"`
	UnicodeEscapeSequence          bool     `json:"unicodeEscapeSequence"`
}

Jump to